Trait HasErrorType

pub trait HasErrorType {
    type Error: Debug;
}
This is used for contexts to declare that they have a unique Self::Error type.

Although it is possible for each context to declare their own associated Error type, doing so may result in having multiple ambiguous Self::Error types, if there are multiple associated types with the same name in different traits.

As a result, it is better for context traits to include HasError as their parent traits, so that multiple traits can all refer to the same abstract Self::Error type.

The Error associated type is also required to implement Debug. This is to allow Self::Error to be used in calls like .unwrap(), as well as for simpler error logging.

More details about how to use HasErrorType is available at https://patterns.contextgeneric.dev/error-handling.html

Required Associated Types

Implementors

Source

impl<Context> HasErrorType for Context
where Context: HasCgpProvider, Context::CgpProvider: ErrorTypeProvider<Context>,

This is used for contexts to declare that they have a unique Self::Error type.

Although it is possible for each context to declare their own associated Error type, doing so may result in having multiple ambiguous Self::Error types, if there are multiple associated types with the same name in different traits.

As a result, it is better for context traits to include HasError as their parent traits, so that multiple traits can all refer to the same abstract Self::Error type.

The Error associated type is also required to implement Debug. This is to allow Self::Error to be used in calls like .unwrap(), as well as for simpler error logging.

More details about how to use HasErrorType is available at https://patterns.contextgeneric.dev/error-handling.html

Source

type Error = <<Context as HasCgpProvider>::CgpProvider as ErrorTypeProvider<Context>>::Error