pub trait ErrorRaiser<__Context__, SourceError>: IsProviderFor<ErrorRaiserComponent, __Context__, SourceError>where
__Context__: HasErrorType,{
// Required method
fn raise_error(error: SourceError) -> <__Context__ as HasErrorType>::Error;
}Expand description
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
Required Methods
fn raise_error(error: SourceError) -> <__Context__ as HasErrorType>::Error
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<__Context__, SourceError, __Components__, __Delegate__> ErrorRaiser<__Context__, SourceError> for UseDelegate<__Components__>where
__Context__: HasErrorType,
__Components__: DelegateComponent<SourceError, Delegate = __Delegate__>,
__Delegate__: ErrorRaiser<__Context__, SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
impl<__Context__, SourceError, __Components__, __Delegate__> ErrorRaiser<__Context__, SourceError> for UseDelegate<__Components__>where
__Context__: HasErrorType,
__Components__: DelegateComponent<SourceError, Delegate = __Delegate__>,
__Delegate__: ErrorRaiser<__Context__, SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
fn raise_error(error: SourceError) -> <__Context__ as HasErrorType>::Error
Sourceimpl<__Context__, SourceError, __Components__, __Path__> ErrorRaiser<__Context__, SourceError> for RedirectLookup<__Components__, __Path__>where
__Context__: HasErrorType,
__Path__: ConcatPath<PathCons<SourceError, Nil>>,
__Components__: DelegateComponent<<__Path__ as ConcatPath<PathCons<SourceError, Nil>>>::Output>,
<__Components__ as DelegateComponent<<__Path__ as ConcatPath<PathCons<SourceError, Nil>>>::Output>>::Delegate: ErrorRaiser<__Context__, SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
impl<__Context__, SourceError, __Components__, __Path__> ErrorRaiser<__Context__, SourceError> for RedirectLookup<__Components__, __Path__>where
__Context__: HasErrorType,
__Path__: ConcatPath<PathCons<SourceError, Nil>>,
__Components__: DelegateComponent<<__Path__ as ConcatPath<PathCons<SourceError, Nil>>>::Output>,
<__Components__ as DelegateComponent<<__Path__ as ConcatPath<PathCons<SourceError, Nil>>>::Output>>::Delegate: ErrorRaiser<__Context__, SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
fn raise_error(error: SourceError) -> <__Context__ as HasErrorType>::Error
Sourceimpl<__Context__, SourceError> ErrorRaiser<__Context__, SourceError> for UseContextwhere
__Context__: HasErrorType + CanRaiseError<SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
impl<__Context__, SourceError> ErrorRaiser<__Context__, SourceError> for UseContextwhere
__Context__: HasErrorType + CanRaiseError<SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.
fn raise_error(error: SourceError) -> <__Context__ as HasErrorType>::Error
Implementors
impl<__Provider__, __Context__, SourceError> ErrorRaiser<__Context__, SourceError> for __Provider__where
__Context__: HasErrorType,
__Provider__: DelegateComponent<ErrorRaiserComponent> + IsProviderFor<ErrorRaiserComponent, __Context__, SourceError>,
<__Provider__ as DelegateComponent<ErrorRaiserComponent>>::Delegate: ErrorRaiser<__Context__, SourceError>,
The CanRaiseError trait is used to raise any concrete error type into
an abstract error provided by HasErrorType.