ErrorRaiser

Trait ErrorRaiser 

pub trait ErrorRaiser<__Context__, SourceError>: IsProviderFor<ErrorRaiserComponent, __Context__, SourceError>
where __Context__: HasErrorType,
{ // Required method fn raise_error(error: SourceError) -> __Context__::Error; }
The CanRaiseError trait is used to raise any concrete error type into an abstract error provided by HasErrorType.

Required Methods

fn raise_error(error: SourceError) -> __Context__::Error

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<__Context__, SourceError, __Components__, __Delegate__> ErrorRaiser<__Context__, SourceError> for UseDelegate<__Components__>
where __Context__: HasErrorType, __Components__: DelegateComponent<SourceError, Delegate = __Delegate__>, __Delegate__: ErrorRaiser<__Context__, SourceError>,

The CanRaiseError trait is used to raise any concrete error type into an abstract error provided by HasErrorType.

Source

fn raise_error(error: SourceError) -> __Context__::Error

Source

impl<__Context__, SourceError> ErrorRaiser<__Context__, SourceError> for UseContext
where __Context__: HasErrorType + CanRaiseError<SourceError>,

The CanRaiseError trait is used to raise any concrete error type into an abstract error provided by HasErrorType.

Source

fn raise_error(error: SourceError) -> __Context__::Error

Implementors

Source

impl<__Component__, __Context__, SourceError> ErrorRaiser<__Context__, SourceError> for __Component__
where __Context__: HasErrorType, __Component__: DelegateComponent<ErrorRaiserComponent> + IsProviderFor<ErrorRaiserComponent, __Context__, SourceError>, __Component__::Delegate: ErrorRaiser<__Context__, SourceError>,

The CanRaiseError trait is used to raise any concrete error type into an abstract error provided by HasErrorType.